/* ----------------------------------------------------------------------------
 *
 * Raima Database Manager
 *
 * Copyright (c) 2019 Raima Inc.,  All rights reserved.
 *
 * Use of this software, whether in source code format, or in executable,
 * binary object code form, is governed by the Raima LICENSE which
 * is fully described in the LICENSE.TXT file, included within this
 * distribution of files.
 *
 * ----------------------------------------------------------------------------
 */
/*! \file
 *
 *   \brief Standard Error Print Routine for C POPCORN Examples
 */
#include "rdmretcodetypes.h"

/*! \page prterror print_error Function
 *
 * This is a common error routine used for all of the C popcorn examples. The
 * function provides a common error display format which shows the line number
 * where this function was called and displays the \c RDM_RETCODE mnemonic for
 * the numeric status code and its description.
 *
 * The following \c rdmretcodeapi.h functions illustrated are:
 *
 * \li rdm_retcodeGetName()
 * \li rdm_retcodeGetDescription()
 */

/*! \brief Standard error print macro */
#define print_error(rc) print_errorEx (rc, __FILE__, __LINE__)

/*! \brief Standard error print format for popcorn examples
 *
 *  This demonstrates the usage of the rdm_retcodeGetName() and
 * rdm_retcodeGetDescription() functions.
 */
void print_errorEx (
    RDM_RETCODE rc,   /**< [in] RDM_RETCODE to analyze */
    const char *file, /**< [in] Sourcec filename */
    int line)         /**< [in] Lineno in source file */
    ;

#pragma once
