/* ----------------------------------------------------------------------------
 * Raima Database Manager
 *
 * Copyright (c) 2014 Raima Inc.,  All rights reserved.
 *
 * Use of this software, whether in source code format, or in executable,
 * binary object code form, is governed by the Raima LICENSE which
 * is fully described in the LICENSE.TXT file, included within this
 * distribution of files.
 * ----------------------------------------------------------------------------
 */

/** \file rdmrowidapi.h
 *  \brief Header for the RDM rowid APIs
 */

#include "rdmrowidtypes.h"

/**
 *
 * \defgroup rowid RDM rowid API
 * \ingroup datatypes
 *
 * The RDM rowid datatype API.  The functions here are located in \lib{base}
 *
 * \addtogroup rowid
 * @{*/

#if defined(__cplusplus)
extern "C" {
#endif

/** \brief Decode a ROWID into a union number and slot

    This function will decode a ROWID into its parts: a union number
    and a slot number.

    The union number is 0 for the first database and one higher for
    each additional database in the union.  The union number is 0 for
    a single database.

    The slot is the row ID as it is stored in the individual
    databases.  For a single database the row ID and the slot are the
    same.

    \par Locking Requirements
    None

    \see rdm_rowidEncode

    \returns The slot number encoded in the ROWID
*/
RDM_EXPORT RDM_SLOT EXTERNAL_FCN rdm_rowidDecode (
    RDM_ROWID_T rowid, /**< [in] The ROWID */
    RDM_UNO *uno       /**< [out] The union number (optional) */
);

/** \brief Encode a union number and slot into a ROWID

    This function will encode a ROWID from its parts: a union number and a
    slot number.

    \par Locking Requirements
    None

    \returns A ROWID

    \see rdm_rdm_rowidDecode
*/
RDM_EXPORT RDM_ROWID_T EXTERNAL_FCN rdm_rowidEncode (
    RDM_UNO uno,  /**< [in] The union number */
    RDM_SLOT slot /**< [in] The slot number */
);

#if defined(__cplusplus)
}
#endif

/** @}*/
