/* ----------------------------------------------------------------------------
 * Raima Database Manager
 *
 * Copyright (c) 2010 Raima Inc.,  All rights reserved.
 *
 * Use of this software, whether in source code format, or in executable,
 * binary object code form, is governed by the Raima LICENSE which
 * is fully described in the LICENSE.TXT file, included within this
 * distribution of files.
 * ----------------------------------------------------------------------------
 */

/** \file rdmtimetzapi.h
 *  \brief Header for the public time with timezone API
 */

#include "rdmdatetimetypes.h"
#include "rdmretcodetypes.h"

#if defined(RDM_UNICODE)
#define rdm_timetzNowAsString RDM_T_FUNC (rdm_timetzNowAsString)
#define rdm_timetzFromString RDM_T_FUNC (rdm_timetzFromString)
#define rdm_timetzToString RDM_T_FUNC (rdm_timetzToString)
#endif

/** \addtogroup time
 * @{
 */

#if defined(__cplusplus)
extern "C" {
#endif

/** \brief Get current time with timezone as a string
 *
 *  Get the current time with timezone as a string.
 *
 *  \retval{sOKAY}
 *  \retval{eBASE_INVTIMEZONE}
 *  \retval{sTRUNCATE}
 *
 *  \see rdm_timetzNow
 */
RDM_EXPORT RDM_RETCODE EXTERNAL_FCN rdm_timetzNowAsString (
    int16_t time_zone,    /**< [in]  Timezone value (in min) */
    RDM_TCHAR_T *timebuf, /**< [out] The current time with timezone */
    size_t buflen /**< [in]  Size of timebuf in number of ASCII characters it can hold */
);

/** \brief Convert a string to a time
 *
 *  Convert a string to a packed time with timezone.
 *
 *  \retval{sOKAY}
 *  \retval{eINVLITERAL}
 *  \retval{eRANGE}
 */
RDM_EXPORT RDM_RETCODE EXTERNAL_FCN rdm_timetzFromString (
    const RDM_TCHAR_T *str,  /**< [in] The string to be converted */
    RDM_PACKED_TIMETZ_T *ptz /**< [out] The packed time with timezone. The
                                buffer need to be allocated by the caller. */
);

/** \brief Get the current time with timezone
 *
 *  Get the current time with timezone.
 *
 *  \retval{sOKAY}
 *  \retval{eBASE_INVTIMEZONE}
 */
RDM_EXPORT RDM_RETCODE EXTERNAL_FCN rdm_timetzNow (
    int16_t time_zone,       /**< [in] Timezone value */
    RDM_PACKED_TIMETZ_T *ptz /**< [out] The current time with timezone */
);

/** \brief Convert a time with timezone to local time
 *
 *  Convert a packed time with timezone to packed local time.
 *
 * \retval{sOKAY}
 */
RDM_EXPORT RDM_RETCODE EXTERNAL_FCN rdm_timetzToTime (
    RDM_PACKED_TIMETZ_T timetzVal, /**< [in]  time with timezone value */
    int16_t tz_disp,               /**< [in]  The local timezone */
    RDM_PACKED_TIME_T *pTimeVal    /**< [out] resulting local time value */
);

/** \brief Convert a time with timezone to a string
 *
 *  Convert a packed time with timezone to a string.
 *
 *  \retval{sOKAY}
 *  \retval{eINVLITERAL}
 *  \retval{sTRUNCATE}
 */
RDM_EXPORT RDM_RETCODE EXTERNAL_FCN rdm_timetzToString (
    RDM_PACKED_TIMETZ_T timetzVal, /**< [in]  time with timezone value */
    RDM_TIME_FORMAT time_fmt,      /**< [in]  RDM time format */
    RDM_TCHAR_T *buf,              /**< [out] result time string */
    size_t bufSize, /**< [in]  buffer size in number of ASCII characters it can hold */
    size_t *puSize /**< [out] resulting size in number of characters */
);

/** \brief Get the time at the start of a day
 *
 *  Get the packed time at the start of the day (midnight).
 *
 *  \return The time at the start of the day
 */
RDM_EXPORT RDM_PACKED_TIMETZ_T EXTERNAL_FCN rdm_timetzZero (void);

#if defined(__cplusplus)
}
#endif

/** @}*/
